searchData={"items":[{"type":"module","title":"Deputy","doc":"Deputy is an Elixir client for the Deputy API.","ref":"Deputy.html"},{"type":"module","title":"Configuration - Deputy","doc":"You can configure the Deputy client with:\n\n```elixir\nclient = Deputy.new(\n  base_url: \"https://your-subdomain.deputy.com\",\n  api_key: \"your-api-key\"\n)\n```","ref":"Deputy.html#module-configuration"},{"type":"module","title":"Usage Example - Deputy","doc":"```elixir\n# Create a client\nclient = Deputy.new(\n  base_url: \"https://your-subdomain.deputy.com\",\n  api_key: \"your-api-key\"\n)\n\n# Get locations\n{:ok, locations} = Deputy.Locations.get_locations(client)\n\n# Error handling\ncase Deputy.Locations.get_location(client, 12345) do\n  {:ok, location} ->\n    # Process location data\n    IO.inspect(location)\n\n  {:error, %Deputy.Error.API{status: 404}} ->\n    # Handle not found error\n    IO.puts(\"Location not found\")\n\n  {:error, %Deputy.Error.HTTP{reason: reason}} ->\n    # Handle HTTP error\n    IO.puts(\"HTTP error: \" <> inspect(reason))\n\n  {:error, %Deputy.Error.RateLimitError{retry_after: seconds}} ->\n    # Handle rate limit\n    IO.puts(\"Rate limited. Try again in \" <> to_string(seconds) <> \" seconds\")\nend\n```","ref":"Deputy.html#module-usage-example"},{"type":"function","title":"Deputy.new/1","doc":"Creates a new Deputy client with the given configuration.","ref":"Deputy.html#new/1"},{"type":"function","title":"Options - Deputy.new/1","doc":"* `:base_url` - Required. The base URL for the Deputy API.\n* `:api_key` - Required. The API key for authentication.\n* `:http_client` - Optional. Module implementing the HTTPClient behavior. Defaults to Deputy.HTTPClient.Req.","ref":"Deputy.html#new/1-options"},{"type":"function","title":"Examples - Deputy.new/1","doc":"iex> Deputy.new(base_url: \"https://your-subdomain.deputy.com\", api_key: \"your-api-key\")\n    %Deputy{base_url: \"https://your-subdomain.deputy.com\", api_key: \"your-api-key\", http_client: Deputy.HTTPClient.Req}","ref":"Deputy.html#new/1-examples"},{"type":"function","title":"Deputy.request/4","doc":"Makes a HTTP request to the Deputy API.\n\nThis is used internally by the API module functions.","ref":"Deputy.html#request/4"},{"type":"function","title":"Returns - Deputy.request/4","doc":"* `{:ok, response_body}` - Successful API call with response body\n* `{:error, error}` - Error from an API call where `error` is one of:\n  * `%Deputy.Error.API{}` - API error with details from Deputy\n  * `%Deputy.Error.HTTP{}` - HTTP transport-level error\n  * `%Deputy.Error.RateLimitError{}` - Rate limit exceeded\n  * `%Deputy.Error.ParseError{}` - Failed to parse response\n  * `%Deputy.Error.ValidationError{}` - Validation of request parameters failed","ref":"Deputy.html#request/4-returns"},{"type":"function","title":"Deputy.request!/4","doc":"Makes a HTTP request to the Deputy API.\n\nRaises an exception if the API call returns an error.","ref":"Deputy.html#request!/4"},{"type":"function","title":"Examples - Deputy.request!/4","doc":"# client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    # locations = Deputy.request!(client, :get, \"/api/v1/resource/Company\")","ref":"Deputy.html#request!/4-examples"},{"type":"type","title":"Deputy.t/0","doc":"","ref":"Deputy.html#t:t/0"},{"type":"module","title":"Deputy.Departments","doc":"Functions for interacting with departments (operational units) in Deputy.","ref":"Deputy.Departments.html"},{"type":"function","title":"Deputy.Departments.create/2","doc":"Create a department (operational unit).","ref":"Deputy.Departments.html#create/2"},{"type":"function","title":"Parameters - Deputy.Departments.create/2","doc":"- `client`: A Deputy client.\n- `attrs`: A map containing the new department details.","ref":"Deputy.Departments.html#create/2-parameters"},{"type":"function","title":"Department parameters - Deputy.Departments.create/2","doc":"- `intCompanyId`: ID of the company/location.\n- `strOpunitName`: Name of the department.\n- `strAddress`: Address of the department.\n- `strExportName`: Optional. Name to use for exports.\n- `intSortOrder`: Optional. Sort order.\n- `intOpunitType`: Type of operational unit.\n- `LocationId`: Optional. ID of the location.","ref":"Deputy.Departments.html#create/2-department-parameters"},{"type":"function","title":"Examples - Deputy.Departments.create/2","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> attrs = %{\n    ...>   intCompanyId: 1,\n    ...>   strOpunitName: \"Sales\",\n    ...>   strAddress: \"123 Main St\",\n    ...>   intOpunitType: 1\n    ...> }\n    iex> Deputy.Departments.create(client, attrs)\n    {:ok, %{\"Id\" => 123}}","ref":"Deputy.Departments.html#create/2-examples"},{"type":"function","title":"Deputy.Departments.create_multiple/2","doc":"Create multiple departments.","ref":"Deputy.Departments.html#create_multiple/2"},{"type":"function","title":"Parameters - Deputy.Departments.create_multiple/2","doc":"- `client`: A Deputy client.\n- `attrs`: A map containing the array of departments to create.","ref":"Deputy.Departments.html#create_multiple/2-parameters"},{"type":"function","title":"Parameters - Deputy.Departments.create_multiple/2","doc":"- `arrArea`: Array of department objects.","ref":"Deputy.Departments.html#create_multiple/2-parameters"},{"type":"function","title":"Examples - Deputy.Departments.create_multiple/2","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> attrs = %{\n    ...>   arrArea: [\n    ...>     %{\n    ...>       intCompanyId: 1,\n    ...>       strOpunitName: \"Sales\",\n    ...>       strAddress: \"123 Main St\",\n    ...>       intOpunitType: 1\n    ...>     },\n    ...>     %{\n    ...>       intCompanyId: 1,\n    ...>       strOpunitName: \"Marketing\",\n    ...>       strAddress: \"123 Main St\",\n    ...>       intOpunitType: 1\n    ...>     }\n    ...>   ]\n    ...> }\n    iex> Deputy.Departments.create_multiple(client, attrs)\n    {:ok, %{\"success\" => true}}","ref":"Deputy.Departments.html#create_multiple/2-examples"},{"type":"function","title":"Deputy.Departments.delete/2","doc":"Delete an operational unit (department).","ref":"Deputy.Departments.html#delete/2"},{"type":"function","title":"Parameters - Deputy.Departments.delete/2","doc":"- `client`: A Deputy client.\n- `id`: The ID of the department to delete.","ref":"Deputy.Departments.html#delete/2-parameters"},{"type":"function","title":"Examples - Deputy.Departments.delete/2","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> Deputy.Departments.delete(client, 1)\n    {:ok, %{\"success\" => true}}","ref":"Deputy.Departments.html#delete/2-examples"},{"type":"function","title":"Deputy.Departments.list/1","doc":"Get all operational units (departments).","ref":"Deputy.Departments.html#list/1"},{"type":"function","title":"Examples - Deputy.Departments.list/1","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> Deputy.Departments.list(client)\n    {:ok, [%{\"Id\" => 1, \"OpunitName\" => \"Sales\"}]}","ref":"Deputy.Departments.html#list/1-examples"},{"type":"function","title":"Deputy.Departments.query/2","doc":"Retrieve preferred employees for a specific area/department.","ref":"Deputy.Departments.html#query/2"},{"type":"function","title":"Parameters - Deputy.Departments.query/2","doc":"- `client`: A Deputy client.\n- `query`: A map containing the search query.","ref":"Deputy.Departments.html#query/2-parameters"},{"type":"function","title":"Examples - Deputy.Departments.query/2","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> query = %{\n    ...>   join: [],\n    ...>   assoc: [\"RosterEmployeeOperationalUnit\"],\n    ...>   search: %{id: %{field: \"Id\", type: \"eq\", data: 1}}\n    ...> }\n    iex> Deputy.Departments.query(client, query)\n    {:ok, [%{\"Id\" => 1, \"Employees\" => [%{\"Id\" => 123, \"FirstName\" => \"John\"}]}]}","ref":"Deputy.Departments.html#query/2-examples"},{"type":"function","title":"Deputy.Departments.update/3","doc":"Update an operational unit (department).","ref":"Deputy.Departments.html#update/3"},{"type":"function","title":"Parameters - Deputy.Departments.update/3","doc":"- `client`: A Deputy client.\n- `id`: The ID of the department to update.\n- `attrs`: A map containing the fields to update.","ref":"Deputy.Departments.html#update/3-parameters"},{"type":"function","title":"Examples - Deputy.Departments.update/3","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> attrs = %{\n    ...>   intCompanyId: 12,\n    ...>   strOpunitName: \"Updated Department Name\"\n    ...> }\n    iex> Deputy.Departments.update(client, 20, attrs)\n    {:ok, %{\"success\" => true}}","ref":"Deputy.Departments.html#update/3-examples"},{"type":"module","title":"Deputy.Employees","doc":"Functions for interacting with employees in Deputy.","ref":"Deputy.Employees.html"},{"type":"function","title":"Deputy.Employees.add_journal/2","doc":"Post a journal entry for an employee.","ref":"Deputy.Employees.html#add_journal/2"},{"type":"function","title":"Parameters - Deputy.Employees.add_journal/2","doc":"- `client`: A Deputy client.\n- `attrs`: A map containing the journal details.","ref":"Deputy.Employees.html#add_journal/2-parameters"},{"type":"function","title":"Journal parameters - Deputy.Employees.add_journal/2","doc":"- `strComment`: The journal comment.\n- `intEmployeeId`: ID of the employee.","ref":"Deputy.Employees.html#add_journal/2-journal-parameters"},{"type":"function","title":"Examples - Deputy.Employees.add_journal/2","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> Deputy.Employees.add_journal(client, %{strComment: \"Employee performed well today\", intEmployeeId: 1})\n    {:ok, %{\"Id\" => 123}}","ref":"Deputy.Employees.html#add_journal/2-examples"},{"type":"function","title":"Deputy.Employees.add_leave/2","doc":"Add leave for an employee.","ref":"Deputy.Employees.html#add_leave/2"},{"type":"function","title":"Parameters - Deputy.Employees.add_leave/2","doc":"- `client`: A Deputy client.\n- `attrs`: A map containing the leave details.","ref":"Deputy.Employees.html#add_leave/2-parameters"},{"type":"function","title":"Leave parameters - Deputy.Employees.add_leave/2","doc":"- `Status`: Status code for the leave (e.g., 1 for approved).\n- `Employee`: ID of the employee.\n- `DateStart`: Start date in format \"YYYY/MM/DD\".\n- `DateEnd`: End date in format \"YYYY/MM/DD\".\n- `ApprovalComment`: Optional. Comment for the leave approval.\n- `ActionOverlappingRosters`: How to handle overlapping rosters (e.g., 0 to keep).","ref":"Deputy.Employees.html#add_leave/2-leave-parameters"},{"type":"function","title":"Examples - Deputy.Employees.add_leave/2","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> attrs = %{\n    ...>   Status: 1,\n    ...>   Employee: 1,\n    ...>   DateStart: \"2023/01/01\",\n    ...>   DateEnd: \"2023/01/05\",\n    ...>   ApprovalComment: \"Vacation\",\n    ...>   ActionOverlappingRosters: 0\n    ...> }\n    iex> Deputy.Employees.add_leave(client, attrs)\n    {:ok, %{\"Id\" => 123}}","ref":"Deputy.Employees.html#add_leave/2-examples"},{"type":"function","title":"Deputy.Employees.add_location/3","doc":"Add a location to an employee.","ref":"Deputy.Employees.html#add_location/3"},{"type":"function","title":"Parameters - Deputy.Employees.add_location/3","doc":"- `client`: A Deputy client.\n- `employee_id`: The ID of the employee.\n- `company_id`: The ID of the location/company to associate with the employee.","ref":"Deputy.Employees.html#add_location/3-parameters"},{"type":"function","title":"Examples - Deputy.Employees.add_location/3","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> Deputy.Employees.add_location(client, 1, 2)\n    {:ok, %{\"success\" => true}}","ref":"Deputy.Employees.html#add_location/3-examples"},{"type":"function","title":"Deputy.Employees.add_unavailability/2","doc":"Add unavailability for an employee.","ref":"Deputy.Employees.html#add_unavailability/2"},{"type":"function","title":"Parameters - Deputy.Employees.add_unavailability/2","doc":"- `client`: A Deputy client.\n- `attrs`: A map containing the unavailability details.","ref":"Deputy.Employees.html#add_unavailability/2-parameters"},{"type":"function","title":"Unavailability parameters - Deputy.Employees.add_unavailability/2","doc":"- `employee`: ID of the employee.\n- `start`: Map with timestamp for start time.\n- `end`: Map with timestamp for end time.\n- `strComment`: Optional. Comment for the unavailability.\n- `recurrence`: Optional. Map with recurrence pattern.","ref":"Deputy.Employees.html#add_unavailability/2-unavailability-parameters"},{"type":"function","title":"Examples - Deputy.Employees.add_unavailability/2","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> attrs = %{\n    ...>   employee: 1,\n    ...>   start: %{timestamp: 1657001675},\n    ...>   end: %{timestamp: 1657001676},\n    ...>   strComment: \"Weekly appointment\",\n    ...>   recurrence: %{FREQ: \"WEEKLY\", INTERVAL: 1, BYDAY: \"MO\"}\n    ...> }\n    iex> Deputy.Employees.add_unavailability(client, attrs)\n    {:ok, %{\"Id\" => 123}}","ref":"Deputy.Employees.html#add_unavailability/2-examples"},{"type":"function","title":"Deputy.Employees.create/2","doc":"Add a new employee.","ref":"Deputy.Employees.html#create/2"},{"type":"function","title":"Parameters - Deputy.Employees.create/2","doc":"- `client`: A Deputy client.\n- `attrs`: A map containing the new employee details.","ref":"Deputy.Employees.html#create/2-parameters"},{"type":"function","title":"Employee parameters - Deputy.Employees.create/2","doc":"- `strFirstName`: Employee's first name.\n- `strLastName`: Employee's last name.\n- `intCompanyId`: ID of the company/location where the employee works.\n- `intGender`: Integer representing gender (e.g., 1 for male, 2 for female).\n- `strCountryCode`: Country code (e.g., \"US\").\n- `strDob`: Date of birth in format \"YYYY-MM-DD\".\n- `strStartDate`: Employment start date in format \"YYYY-MM-DD\".\n- `strMobilePhone`: Mobile phone number.\n- `strPayrollId`: Optional. Payroll ID.\n- `fltWeekDayRate`: Optional. Weekday pay rate.","ref":"Deputy.Employees.html#create/2-employee-parameters"},{"type":"function","title":"Examples - Deputy.Employees.create/2","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> attrs = %{\n    ...>   strFirstName: \"John\",\n    ...>   strLastName: \"Doe\",\n    ...>   intCompanyId: 1,\n    ...>   intGender: 1,\n    ...>   strCountryCode: \"US\",\n    ...>   strDob: \"1980-01-01\",\n    ...>   strStartDate: \"2023-01-01\",\n    ...>   strMobilePhone: \"5551234567\"\n    ...> }\n    iex> Deputy.Employees.create(client, attrs)\n    {:ok, %{\"Id\" => 123}}","ref":"Deputy.Employees.html#create/2-examples"},{"type":"function","title":"Deputy.Employees.delete/2","doc":"Delete an employee's account in Deputy.","ref":"Deputy.Employees.html#delete/2"},{"type":"function","title":"Parameters - Deputy.Employees.delete/2","doc":"- `client`: A Deputy client.\n- `id`: The ID of the employee to delete.","ref":"Deputy.Employees.html#delete/2-parameters"},{"type":"function","title":"Examples - Deputy.Employees.delete/2","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> Deputy.Employees.delete(client, 1)\n    {:ok, %{\"success\" => true}}","ref":"Deputy.Employees.html#delete/2-examples"},{"type":"function","title":"Deputy.Employees.get/2","doc":"Get employee by ID.","ref":"Deputy.Employees.html#get/2"},{"type":"function","title":"Parameters - Deputy.Employees.get/2","doc":"- `client`: A Deputy client.\n- `id`: The ID of the employee to retrieve.","ref":"Deputy.Employees.html#get/2-parameters"},{"type":"function","title":"Examples - Deputy.Employees.get/2","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> Deputy.Employees.get(client, 1)\n    {:ok, %{\"Id\" => 1, \"FirstName\" => \"John\", \"LastName\" => \"Doe\"}}","ref":"Deputy.Employees.html#get/2-examples"},{"type":"function","title":"Deputy.Employees.get_agreed_hours/2","doc":"Get agreed hours for an employee.","ref":"Deputy.Employees.html#get_agreed_hours/2"},{"type":"function","title":"Parameters - Deputy.Employees.get_agreed_hours/2","doc":"- `client`: A Deputy client.\n- `id`: The ID of the employee.","ref":"Deputy.Employees.html#get_agreed_hours/2-parameters"},{"type":"function","title":"Examples - Deputy.Employees.get_agreed_hours/2","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> Deputy.Employees.get_agreed_hours(client, 1)\n    {:ok, %{\"AgreedHours\" => 40.0}}","ref":"Deputy.Employees.html#get_agreed_hours/2-examples"},{"type":"function","title":"Deputy.Employees.get_leave/2","doc":"Get an employee's leave.","ref":"Deputy.Employees.html#get_leave/2"},{"type":"function","title":"Parameters - Deputy.Employees.get_leave/2","doc":"- `client`: A Deputy client.\n- `id`: The ID of the employee.","ref":"Deputy.Employees.html#get_leave/2-parameters"},{"type":"function","title":"Examples - Deputy.Employees.get_leave/2","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> Deputy.Employees.get_leave(client, 1)\n    {:ok, [%{\"Id\" => 123, \"DateStart\" => \"2023-01-01\", \"DateEnd\" => \"2023-01-05\"}]}","ref":"Deputy.Employees.html#get_leave/2-examples"},{"type":"function","title":"Deputy.Employees.get_shift_info/2","doc":"Get an employee's current shift information.","ref":"Deputy.Employees.html#get_shift_info/2"},{"type":"function","title":"Parameters - Deputy.Employees.get_shift_info/2","doc":"- `client`: A Deputy client.\n- `id`: The ID of the employee.","ref":"Deputy.Employees.html#get_shift_info/2-parameters"},{"type":"function","title":"Examples - Deputy.Employees.get_shift_info/2","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> Deputy.Employees.get_shift_info(client, 1)\n    {:ok, %{\"Status\" => \"On Shift\", \"RosterID\" => 123}}","ref":"Deputy.Employees.html#get_shift_info/2-examples"},{"type":"function","title":"Deputy.Employees.get_unavailability/2","doc":"Get unavailability details for an employee.","ref":"Deputy.Employees.html#get_unavailability/2"},{"type":"function","title":"Parameters - Deputy.Employees.get_unavailability/2","doc":"- `client`: A Deputy client.\n- `id`: The ID of the employee.","ref":"Deputy.Employees.html#get_unavailability/2-parameters"},{"type":"function","title":"Examples - Deputy.Employees.get_unavailability/2","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> Deputy.Employees.get_unavailability(client, 1)\n    {:ok, [%{\"Id\" => 123, \"Start\" => %{\"timestamp\" => 1657001675}, \"End\" => %{\"timestamp\" => 1657001676}}]}","ref":"Deputy.Employees.html#get_unavailability/2-examples"},{"type":"function","title":"Deputy.Employees.invite/2","doc":"Invite an employee to Deputy.","ref":"Deputy.Employees.html#invite/2"},{"type":"function","title":"Parameters - Deputy.Employees.invite/2","doc":"- `client`: A Deputy client.\n- `id`: The ID of the employee to invite.","ref":"Deputy.Employees.html#invite/2-parameters"},{"type":"function","title":"Examples - Deputy.Employees.invite/2","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> Deputy.Employees.invite(client, 1)\n    {:ok, %{\"success\" => true}}","ref":"Deputy.Employees.html#invite/2-examples"},{"type":"function","title":"Deputy.Employees.list/1","doc":"Get all employees.","ref":"Deputy.Employees.html#list/1"},{"type":"function","title":"Examples - Deputy.Employees.list/1","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> Deputy.Employees.list(client)\n    {:ok, [%{\"Id\" => 1, \"FirstName\" => \"John\", \"LastName\" => \"Doe\"}]}","ref":"Deputy.Employees.html#list/1-examples"},{"type":"function","title":"Deputy.Employees.reactivate/2","doc":"Reactivate a terminated employee.","ref":"Deputy.Employees.html#reactivate/2"},{"type":"function","title":"Parameters - Deputy.Employees.reactivate/2","doc":"- `client`: A Deputy client.\n- `id`: The ID of the employee to reactivate.","ref":"Deputy.Employees.html#reactivate/2-parameters"},{"type":"function","title":"Examples - Deputy.Employees.reactivate/2","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> Deputy.Employees.reactivate(client, 1)\n    {:ok, %{\"success\" => true}}","ref":"Deputy.Employees.html#reactivate/2-examples"},{"type":"function","title":"Deputy.Employees.remove_location/3","doc":"Remove a location from an employee.","ref":"Deputy.Employees.html#remove_location/3"},{"type":"function","title":"Parameters - Deputy.Employees.remove_location/3","doc":"- `client`: A Deputy client.\n- `employee_id`: The ID of the employee.\n- `company_id`: The ID of the location/company to remove from the employee.","ref":"Deputy.Employees.html#remove_location/3-parameters"},{"type":"function","title":"Examples - Deputy.Employees.remove_location/3","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> Deputy.Employees.remove_location(client, 1, 2)\n    {:ok, %{\"success\" => true}}","ref":"Deputy.Employees.html#remove_location/3-examples"},{"type":"function","title":"Deputy.Employees.set_award/3","doc":"Set award for an employee.","ref":"Deputy.Employees.html#set_award/3"},{"type":"function","title":"Parameters - Deputy.Employees.set_award/3","doc":"- `client`: A Deputy client.\n- `id`: The ID of the employee.\n- `attrs`: A map containing the award details.","ref":"Deputy.Employees.html#set_award/3-parameters"},{"type":"function","title":"Award parameters - Deputy.Employees.set_award/3","doc":"- `strCountryCode`: Country code (e.g., \"au\").\n- `strAwardCode`: Award code.","ref":"Deputy.Employees.html#set_award/3-award-parameters"},{"type":"function","title":"Examples - Deputy.Employees.set_award/3","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> Deputy.Employees.set_award(client, 1, %{strCountryCode: \"au\", strAwardCode: \"casual-2021-11-01-aea-2\"})\n    {:ok, %{\"success\" => true}}","ref":"Deputy.Employees.html#set_award/3-examples"},{"type":"function","title":"Deputy.Employees.terminate/2","doc":"Terminate an employee.","ref":"Deputy.Employees.html#terminate/2"},{"type":"function","title":"Parameters - Deputy.Employees.terminate/2","doc":"- `client`: A Deputy client.\n- `id`: The ID of the employee to terminate.","ref":"Deputy.Employees.html#terminate/2-parameters"},{"type":"function","title":"Examples - Deputy.Employees.terminate/2","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> Deputy.Employees.terminate(client, 1)\n    {:ok, %{\"success\" => true}}","ref":"Deputy.Employees.html#terminate/2-examples"},{"type":"function","title":"Deputy.Employees.update/3","doc":"Update an existing employee.","ref":"Deputy.Employees.html#update/3"},{"type":"function","title":"Parameters - Deputy.Employees.update/3","doc":"- `client`: A Deputy client.\n- `id`: The ID of the employee to update.\n- `attrs`: A map containing the fields to update.","ref":"Deputy.Employees.html#update/3-parameters"},{"type":"function","title":"Examples - Deputy.Employees.update/3","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> Deputy.Employees.update(client, 1, %{Phone: \"5559876543\"})\n    {:ok, %{\"success\" => true}}","ref":"Deputy.Employees.html#update/3-examples"},{"type":"module","title":"Deputy.Error","doc":"Error types for Deputy API client operations.\n\nThis module provides standardized error structs for different types of errors that can occur\nwhen interacting with the Deputy API.","ref":"Deputy.Error.html"},{"type":"function","title":"Deputy.Error.from_response/1","doc":"Converts a raw HTTP error response into the appropriate error struct.\n\nThis function analyzes the HTTP response and creates a specific error struct\nbased on the status code and response body structure.","ref":"Deputy.Error.html#from_response/1"},{"type":"type","title":"Deputy.Error.t/0","doc":"","ref":"Deputy.Error.html#t:t/0"},{"type":"behaviour","title":"Deputy.HTTPClient","doc":"Behavior for HTTP clients used by Deputy","ref":"Deputy.HTTPClient.html"},{"type":"callback","title":"Deputy.HTTPClient.request/1","doc":"","ref":"Deputy.HTTPClient.html#c:request/1"},{"type":"behaviour","title":"Deputy.HTTPClient.Behaviour","doc":"Behavior for HTTP clients used by Deputy","ref":"Deputy.HTTPClient.Behaviour.html"},{"type":"callback","title":"Deputy.HTTPClient.Behaviour.request/1","doc":"","ref":"Deputy.HTTPClient.Behaviour.html#c:request/1"},{"type":"module","title":"Deputy.HTTPClient.Req","doc":"HTTP client implementation using Req","ref":"Deputy.HTTPClient.Req.html"},{"type":"module","title":"Deputy.Locations","doc":"Functions for interacting with locations (companies) in Deputy.","ref":"Deputy.Locations.html"},{"type":"function","title":"Deputy.Locations.archive/2","doc":"Archive a location.","ref":"Deputy.Locations.html#archive/2"},{"type":"function","title":"Parameters - Deputy.Locations.archive/2","doc":"- `client`: A Deputy client.\n- `id`: The ID of the location to archive.","ref":"Deputy.Locations.html#archive/2-parameters"},{"type":"function","title":"Examples - Deputy.Locations.archive/2","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> Deputy.Locations.archive(client, 1)\n    {:ok, %{\"success\" => true}}","ref":"Deputy.Locations.html#archive/2-examples"},{"type":"function","title":"Deputy.Locations.create/2","doc":"Add a new location.","ref":"Deputy.Locations.html#create/2"},{"type":"function","title":"Parameters - Deputy.Locations.create/2","doc":"- `client`: A Deputy client.\n- `attrs`: A map containing the new location details.","ref":"Deputy.Locations.html#create/2-parameters"},{"type":"function","title":"Location parameters - Deputy.Locations.create/2","doc":"- `strWorkplaceName`: String naming the workplace.\n- `strWorkplaceCode`: A string with a length of 3 allowing you to define a short code for the location.\n- `strAddress`: String of the location's address.\n- `strAddressNotes`: Optional. Notes about the address.\n- `intParentCompany`: Optional. Integer ID of parent company.\n- `intIsWorkplace`: Boolean (1 - True, 0 - False) whether the location is considered a workplace.\n- `intIsPayrollEntity`: Boolean (1 - True, 0 - False) whether the location has payroll setup.\n- `strTimezone`: Timezone for the workplace using TZ database naming.\n- `strPayrollExportCode`: Optional. String naming what to use as a code for payroll exports.","ref":"Deputy.Locations.html#create/2-location-parameters"},{"type":"function","title":"Examples - Deputy.Locations.create/2","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> attrs = %{\n    ...>   strWorkplaceName: \"New Location\",\n    ...>   strWorkplaceCode: \"NLC\",\n    ...>   strAddress: \"123 Test St\",\n    ...>   intIsWorkplace: 1,\n    ...>   intIsPayrollEntity: 1,\n    ...>   strTimezone: \"America/New_York\"\n    ...> }\n    iex> Deputy.Locations.create(client, attrs)\n    {:ok, %{\"Id\" => 123}}","ref":"Deputy.Locations.html#create/2-examples"},{"type":"function","title":"Deputy.Locations.create_workplace/2","doc":"Add a new workplace with areas.","ref":"Deputy.Locations.html#create_workplace/2"},{"type":"function","title":"Parameters - Deputy.Locations.create_workplace/2","doc":"- `client`: A Deputy client.\n- `attrs`: A map containing the new workplace details.","ref":"Deputy.Locations.html#create_workplace/2-parameters"},{"type":"function","title":"Workplace parameters - Deputy.Locations.create_workplace/2","doc":"- `strWorkplaceName`: String naming the workplace.\n- `strWorkplaceTimezone`: Timezone for the workplace using TZ database naming.\n- `strAddress`: String of the location's address.\n- `strLat`: The latitude of the location using a string.\n- `strLon`: The longitude of the location using a string.\n- `intCountry`: An integer which defines which country the location is in.\n- `arrAreaNames`: An array of the area names to add to the location.\n- `strWorkplaceCode`: A string with a length of 3 allowing you to define a short code for the location.\n- `strPayrollExportCode`: Optional. String naming what to use as a code for payroll exports.\n- `blnIsWorkplace`: Boolean (1 - True, 0 - False) whether the location is considered a workplace.\n- `blnIsPayrollEntity`: Boolean (1 - True, 0 - False) whether the location has payroll setup.","ref":"Deputy.Locations.html#create_workplace/2-workplace-parameters"},{"type":"function","title":"Examples - Deputy.Locations.create_workplace/2","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> attrs = %{\n    ...>   strWorkplaceName: \"New Workplace\",\n    ...>   strWorkplaceTimezone: \"America/New_York\",\n    ...>   strAddress: \"123 Test St\",\n    ...>   strLat: \"40.7128\",\n    ...>   strLon: \"-74.0060\",\n    ...>   intCountry: 1,\n    ...>   arrAreaNames: [\"Reception\", \"Kitchen\"],\n    ...>   strWorkplaceCode: \"NWP\",\n    ...>   blnIsWorkplace: 1,\n    ...>   blnIsPayrollEntity: 1\n    ...> }\n    iex> Deputy.Locations.create_workplace(client, attrs)\n    {:ok, %{\"Id\" => 123}}","ref":"Deputy.Locations.html#create_workplace/2-examples"},{"type":"function","title":"Deputy.Locations.delete/2","doc":"Delete a location.","ref":"Deputy.Locations.html#delete/2"},{"type":"function","title":"Parameters - Deputy.Locations.delete/2","doc":"- `client`: A Deputy client.\n- `id`: The ID of the location to delete.","ref":"Deputy.Locations.html#delete/2-parameters"},{"type":"function","title":"Examples - Deputy.Locations.delete/2","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> Deputy.Locations.delete(client, 1)\n    {:ok, %{\"success\" => true}}","ref":"Deputy.Locations.html#delete/2-examples"},{"type":"function","title":"Deputy.Locations.get/2","doc":"Get location by ID.","ref":"Deputy.Locations.html#get/2"},{"type":"function","title":"Parameters - Deputy.Locations.get/2","doc":"- `client`: A Deputy client.\n- `id`: The ID of the location to retrieve.","ref":"Deputy.Locations.html#get/2-parameters"},{"type":"function","title":"Examples - Deputy.Locations.get/2","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> Deputy.Locations.get(client, 1)\n    {:ok, %{\"Id\" => 1, \"CompanyName\" => \"Test Company\"}}","ref":"Deputy.Locations.html#get/2-examples"},{"type":"function","title":"Deputy.Locations.get_settings/2","doc":"Get a location's settings.","ref":"Deputy.Locations.html#get_settings/2"},{"type":"function","title":"Parameters - Deputy.Locations.get_settings/2","doc":"- `client`: A Deputy client.\n- `id`: The ID of the location to retrieve settings for.","ref":"Deputy.Locations.html#get_settings/2-parameters"},{"type":"function","title":"Examples - Deputy.Locations.get_settings/2","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> Deputy.Locations.get_settings(client, 1)\n    {:ok, %{\"WEEK_START\" => 1}}\n\n    # Using the bang version\n    iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> Deputy.Locations.get_settings!(client, 1)\n    %{\"WEEK_START\" => 1}\n\n    # Error handling\n    iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> case Deputy.Locations.get_settings(client, 1) do\n    ...>   {:ok, settings} -> settings\n    ...>   {:error, %Deputy.Error.API{status: 404}} -> \"Location not found\"\n    ...>   {:error, %Deputy.Error.HTTP{reason: reason}} -> \"HTTP error: \" <> inspect(reason)\n    ...> end","ref":"Deputy.Locations.html#get_settings/2-examples"},{"type":"function","title":"Deputy.Locations.get_settings!/2","doc":"Get a location's settings. Raises an exception if the API call returns an error.","ref":"Deputy.Locations.html#get_settings!/2"},{"type":"function","title":"Parameters - Deputy.Locations.get_settings!/2","doc":"- `client`: A Deputy client.\n- `id`: The ID of the location to retrieve settings for.","ref":"Deputy.Locations.html#get_settings!/2-parameters"},{"type":"function","title":"Examples - Deputy.Locations.get_settings!/2","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> Deputy.Locations.get_settings!(client, 1)\n    %{\"WEEK_START\" => 1}","ref":"Deputy.Locations.html#get_settings!/2-examples"},{"type":"function","title":"Deputy.Locations.list/1","doc":"Get all locations.","ref":"Deputy.Locations.html#list/1"},{"type":"function","title":"Examples - Deputy.Locations.list/1","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> Deputy.Locations.list(client)\n    {:ok, [%{\"Id\" => 1, \"CompanyName\" => \"Test Company\"}]}\n\n    # Using the bang version\n    iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> Deputy.Locations.list!(client)\n    [%{\"Id\" => 1, \"CompanyName\" => \"Test Company\"}]\n\n    # Error handling\n    iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> case Deputy.Locations.list(client) do\n    ...>   {:ok, locations} -> locations\n    ...>   {:error, %Deputy.Error.API{status: 403}} -> \"Permission denied\"\n    ...>   {:error, %Deputy.Error.HTTP{reason: reason}} -> \"HTTP error: \" <> inspect(reason)\n    ...> end","ref":"Deputy.Locations.html#list/1-examples"},{"type":"function","title":"Deputy.Locations.list!/1","doc":"Get all locations. Raises an exception if the API call returns an error.","ref":"Deputy.Locations.html#list!/1"},{"type":"function","title":"Examples - Deputy.Locations.list!/1","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> Deputy.Locations.list!(client)\n    [%{\"Id\" => 1, \"CompanyName\" => \"Test Company\"}]","ref":"Deputy.Locations.html#list!/1-examples"},{"type":"function","title":"Deputy.Locations.list_simplified/1","doc":"Get a simplified list of locations.","ref":"Deputy.Locations.html#list_simplified/1"},{"type":"function","title":"Examples - Deputy.Locations.list_simplified/1","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> Deputy.Locations.list_simplified(client)\n    {:ok, [%{\"Id\" => 1, \"CompanyName\" => \"Test Company\"}]}\n\n    # Using the bang version\n    iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> Deputy.Locations.list_simplified!(client)\n    [%{\"Id\" => 1, \"CompanyName\" => \"Test Company\"}]\n\n    # Error handling\n    iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> case Deputy.Locations.list_simplified(client) do\n    ...>   {:ok, locations} -> locations\n    ...>   {:error, %Deputy.Error.API{status: 403}} -> \"Permission denied\"\n    ...>   {:error, %Deputy.Error.HTTP{reason: reason}} -> \"HTTP error: \" <> inspect(reason)\n    ...> end","ref":"Deputy.Locations.html#list_simplified/1-examples"},{"type":"function","title":"Deputy.Locations.list_simplified!/1","doc":"Get a simplified list of locations. Raises an exception if the API call returns an error.","ref":"Deputy.Locations.html#list_simplified!/1"},{"type":"function","title":"Examples - Deputy.Locations.list_simplified!/1","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> Deputy.Locations.list_simplified!(client)\n    [%{\"Id\" => 1, \"CompanyName\" => \"Test Company\"}]","ref":"Deputy.Locations.html#list_simplified!/1-examples"},{"type":"function","title":"Deputy.Locations.update/3","doc":"Update a location.","ref":"Deputy.Locations.html#update/3"},{"type":"function","title":"Parameters - Deputy.Locations.update/3","doc":"- `client`: A Deputy client.\n- `id`: The ID of the location to update.\n- `attrs`: A map containing the fields to update.","ref":"Deputy.Locations.html#update/3-parameters"},{"type":"function","title":"Examples - Deputy.Locations.update/3","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> Deputy.Locations.update(client, 1, %{strWorkplaceCode: \"UPD\"})\n    {:ok, %{\"success\" => true}}","ref":"Deputy.Locations.html#update/3-examples"},{"type":"function","title":"Deputy.Locations.update_all_settings/2","doc":"Modify settings for all locations.","ref":"Deputy.Locations.html#update_all_settings/2"},{"type":"function","title":"Parameters - Deputy.Locations.update_all_settings/2","doc":"- `client`: A Deputy client.\n- `settings`: A map of settings to update.","ref":"Deputy.Locations.html#update_all_settings/2-parameters"},{"type":"function","title":"Examples - Deputy.Locations.update_all_settings/2","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> Deputy.Locations.update_all_settings(client, %{\"WEEK_START\" => 2})\n    {:ok, %{\"success\" => true}}\n\n    # Using the bang version\n    iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> Deputy.Locations.update_all_settings!(client, %{\"WEEK_START\" => 2})\n    %{\"success\" => true}\n\n    # Error handling\n    iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> case Deputy.Locations.update_all_settings(client, %{\"WEEK_START\" => 2}) do\n    ...>   {:ok, result} -> \"Settings updated\"\n    ...>   {:error, %Deputy.Error.API{message: message}} -> \"API error: \" <> message\n    ...>   {:error, %Deputy.Error.ValidationError{}} -> \"Invalid settings data\"\n    ...> end","ref":"Deputy.Locations.html#update_all_settings/2-examples"},{"type":"function","title":"Deputy.Locations.update_all_settings!/2","doc":"Modify settings for all locations. Raises an exception if the API call returns an error.","ref":"Deputy.Locations.html#update_all_settings!/2"},{"type":"function","title":"Parameters - Deputy.Locations.update_all_settings!/2","doc":"- `client`: A Deputy client.\n- `settings`: A map of settings to update.","ref":"Deputy.Locations.html#update_all_settings!/2-parameters"},{"type":"function","title":"Examples - Deputy.Locations.update_all_settings!/2","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> Deputy.Locations.update_all_settings!(client, %{\"WEEK_START\" => 2})\n    %{\"success\" => true}","ref":"Deputy.Locations.html#update_all_settings!/2-examples"},{"type":"function","title":"Deputy.Locations.update_settings/3","doc":"Modify settings for a single location.","ref":"Deputy.Locations.html#update_settings/3"},{"type":"function","title":"Parameters - Deputy.Locations.update_settings/3","doc":"- `client`: A Deputy client.\n- `id`: The ID of the location to update settings for.\n- `settings`: A map of settings to update.","ref":"Deputy.Locations.html#update_settings/3-parameters"},{"type":"function","title":"Examples - Deputy.Locations.update_settings/3","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> Deputy.Locations.update_settings(client, 1, %{\"WEEK_START\" => 2})\n    {:ok, %{\"success\" => true}}\n\n    # Using the bang version\n    iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> Deputy.Locations.update_settings!(client, 1, %{\"WEEK_START\" => 2})\n    %{\"success\" => true}\n\n    # Error handling\n    iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> case Deputy.Locations.update_settings(client, 1, %{\"WEEK_START\" => 2}) do\n    ...>   {:ok, result} -> \"Settings updated\"\n    ...>   {:error, %Deputy.Error.API{message: message}} -> \"API error: \" <> message\n    ...>   {:error, %Deputy.Error.HTTP{reason: reason}} -> \"HTTP error: \" <> inspect(reason)\n    ...> end","ref":"Deputy.Locations.html#update_settings/3-examples"},{"type":"function","title":"Deputy.Locations.update_settings!/3","doc":"Modify settings for a single location. Raises an exception if the API call returns an error.","ref":"Deputy.Locations.html#update_settings!/3"},{"type":"function","title":"Parameters - Deputy.Locations.update_settings!/3","doc":"- `client`: A Deputy client.\n- `id`: The ID of the location to update settings for.\n- `settings`: A map of settings to update.","ref":"Deputy.Locations.html#update_settings!/3-parameters"},{"type":"function","title":"Examples - Deputy.Locations.update_settings!/3","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> Deputy.Locations.update_settings!(client, 1, %{\"WEEK_START\" => 2})\n    %{\"success\" => true}","ref":"Deputy.Locations.html#update_settings!/3-examples"},{"type":"module","title":"Deputy.My","doc":"Functions for interacting with endpoints related to the authenticated user.","ref":"Deputy.My.html"},{"type":"function","title":"Deputy.My.all_contact_addresses/1","doc":"Get all the authenticated user's addresses including emergency contacts.","ref":"Deputy.My.html#all_contact_addresses/1"},{"type":"function","title":"Examples - Deputy.My.all_contact_addresses/1","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> Deputy.My.all_contact_addresses(client)\n    {:ok, [%{\"Street1\" => \"123 Main St\", \"City\" => \"New York\"}]}","ref":"Deputy.My.html#all_contact_addresses/1-examples"},{"type":"function","title":"Deputy.My.colleagues/1","doc":"Get the authenticated user's colleagues.","ref":"Deputy.My.html#colleagues/1"},{"type":"function","title":"Examples - Deputy.My.colleagues/1","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> Deputy.My.colleagues(client)\n    {:ok, [%{\"Id\" => 2, \"FirstName\" => \"Jane\", \"LastName\" => \"Smith\"}]}","ref":"Deputy.My.html#colleagues/1-examples"},{"type":"function","title":"Deputy.My.complete_task/2","doc":"Complete a task.","ref":"Deputy.My.html#complete_task/2"},{"type":"function","title":"Parameters - Deputy.My.complete_task/2","doc":"- `client`: A Deputy client.\n- `id`: The ID of the task to complete.","ref":"Deputy.My.html#complete_task/2-parameters"},{"type":"function","title":"Examples - Deputy.My.complete_task/2","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> Deputy.My.complete_task(client, 1)\n    {:ok, %{\"success\" => true}}","ref":"Deputy.My.html#complete_task/2-examples"},{"type":"function","title":"Deputy.My.contact_address/1","doc":"Get the authenticated user's address.","ref":"Deputy.My.html#contact_address/1"},{"type":"function","title":"Examples - Deputy.My.contact_address/1","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> Deputy.My.contact_address(client)\n    {:ok, %{\"Street1\" => \"123 Main St\", \"City\" => \"New York\"}}","ref":"Deputy.My.html#contact_address/1-examples"},{"type":"function","title":"Deputy.My.leave/1","doc":"Get the authenticated user's leave requests.","ref":"Deputy.My.html#leave/1"},{"type":"function","title":"Examples - Deputy.My.leave/1","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> Deputy.My.leave(client)\n    {:ok, [%{\"Id\" => 1, \"DateStart\" => \"2023-01-01\", \"DateEnd\" => \"2023-01-05\"}]}","ref":"Deputy.My.html#leave/1-examples"},{"type":"function","title":"Deputy.My.location/2","doc":"Get a specific location.","ref":"Deputy.My.html#location/2"},{"type":"function","title":"Parameters - Deputy.My.location/2","doc":"- `client`: A Deputy client.\n- `id`: The ID of the location.","ref":"Deputy.My.html#location/2-parameters"},{"type":"function","title":"Examples - Deputy.My.location/2","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> Deputy.My.location(client, 1)\n    {:ok, %{\"Id\" => 1, \"Name\" => \"Main Office\"}}","ref":"Deputy.My.html#location/2-examples"},{"type":"function","title":"Deputy.My.locations/1","doc":"Get locations where the authenticated user can work.","ref":"Deputy.My.html#locations/1"},{"type":"function","title":"Examples - Deputy.My.locations/1","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> Deputy.My.locations(client)\n    {:ok, [%{\"Id\" => 1, \"Name\" => \"Main Office\"}]}","ref":"Deputy.My.html#locations/1-examples"},{"type":"function","title":"Deputy.My.me/1","doc":"Get information about the authenticated user.","ref":"Deputy.My.html#me/1"},{"type":"function","title":"Examples - Deputy.My.me/1","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> Deputy.My.me(client)\n    {:ok, %{\"Id\" => 1, \"FirstName\" => \"John\", \"LastName\" => \"Doe\"}}","ref":"Deputy.My.html#me/1-examples"},{"type":"function","title":"Deputy.My.memos/1","doc":"Get the authenticated user's memos (newsfeed).","ref":"Deputy.My.html#memos/1"},{"type":"function","title":"Examples - Deputy.My.memos/1","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> Deputy.My.memos(client)\n    {:ok, [%{\"Id\" => 1, \"Content\" => \"Welcome to Deputy\"}]}","ref":"Deputy.My.html#memos/1-examples"},{"type":"function","title":"Deputy.My.notifications/1","doc":"Get the authenticated user's notifications.","ref":"Deputy.My.html#notifications/1"},{"type":"function","title":"Examples - Deputy.My.notifications/1","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> Deputy.My.notifications(client)\n    {:ok, [%{\"Id\" => 1, \"Message\" => \"You have a new roster\"}]}","ref":"Deputy.My.html#notifications/1-examples"},{"type":"function","title":"Deputy.My.rosters/1","doc":"Get the authenticated user's rosters.","ref":"Deputy.My.html#rosters/1"},{"type":"function","title":"Examples - Deputy.My.rosters/1","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> Deputy.My.rosters(client)\n    {:ok, [%{\"Id\" => 1, \"StartTime\" => \"2023-01-01T09:00:00\"}]}","ref":"Deputy.My.html#rosters/1-examples"},{"type":"function","title":"Deputy.My.setup/1","doc":"Get setup information for the authenticated user.","ref":"Deputy.My.html#setup/1"},{"type":"function","title":"Examples - Deputy.My.setup/1","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> Deputy.My.setup(client)\n    {:ok, %{\"locations\" => [%{\"Id\" => 1, \"Name\" => \"Main Office\"}]}}","ref":"Deputy.My.html#setup/1-examples"},{"type":"function","title":"Deputy.My.tasks/1","doc":"Get the authenticated user's tasks.","ref":"Deputy.My.html#tasks/1"},{"type":"function","title":"Examples - Deputy.My.tasks/1","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> Deputy.My.tasks(client)\n    {:ok, [%{\"Id\" => 1, \"TaskName\" => \"Complete training\"}]}","ref":"Deputy.My.html#tasks/1-examples"},{"type":"function","title":"Deputy.My.timesheet_detail/2","doc":"Get details for a specific timesheet.","ref":"Deputy.My.html#timesheet_detail/2"},{"type":"function","title":"Parameters - Deputy.My.timesheet_detail/2","doc":"- `client`: A Deputy client.\n- `id`: The ID of the timesheet.","ref":"Deputy.My.html#timesheet_detail/2-parameters"},{"type":"function","title":"Examples - Deputy.My.timesheet_detail/2","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> Deputy.My.timesheet_detail(client, 1)\n    {:ok, %{\"Id\" => 1, \"StartTime\" => \"2023-01-01T09:00:00\"}}","ref":"Deputy.My.html#timesheet_detail/2-examples"},{"type":"function","title":"Deputy.My.timesheets/1","doc":"Get the authenticated user's timesheets.","ref":"Deputy.My.html#timesheets/1"},{"type":"function","title":"Examples - Deputy.My.timesheets/1","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> Deputy.My.timesheets(client)\n    {:ok, [%{\"Id\" => 1, \"StartTime\" => \"2023-01-01T09:00:00\"}]}","ref":"Deputy.My.html#timesheets/1-examples"},{"type":"function","title":"Deputy.My.training/1","doc":"Get the authenticated user's training.","ref":"Deputy.My.html#training/1"},{"type":"function","title":"Examples - Deputy.My.training/1","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> Deputy.My.training(client)\n    {:ok, [%{\"Id\" => 1, \"Name\" => \"Safety Training\"}]}","ref":"Deputy.My.html#training/1-examples"},{"type":"function","title":"Deputy.My.unavailability/1","doc":"Get the authenticated user's unavailability.","ref":"Deputy.My.html#unavailability/1"},{"type":"function","title":"Examples - Deputy.My.unavailability/1","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> Deputy.My.unavailability(client)\n    {:ok, [%{\"Id\" => 1, \"Start\" => %{\"timestamp\" => 1657001675}}]}","ref":"Deputy.My.html#unavailability/1-examples"},{"type":"function","title":"Deputy.My.update_contact_address/2","doc":"Update the authenticated user's address.","ref":"Deputy.My.html#update_contact_address/2"},{"type":"function","title":"Parameters - Deputy.My.update_contact_address/2","doc":"- `client`: A Deputy client.\n- `attrs`: A map containing the address details.","ref":"Deputy.My.html#update_contact_address/2-parameters"},{"type":"function","title":"Address parameters - Deputy.My.update_contact_address/2","doc":"- `ContactName`: Name for the contact.\n- `UnitNo`: Unit number.\n- `Street1`: Street address.\n- `City`: City.\n- `State`: State code.\n- `Postcode`: Postal code.\n- `Country`: Country ID.\n- `Notes`: Optional notes.","ref":"Deputy.My.html#update_contact_address/2-address-parameters"},{"type":"function","title":"Examples - Deputy.My.update_contact_address/2","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> attrs = %{\n    ...>   ContactName: \"John Doe\",\n    ...>   UnitNo: \"2\",\n    ...>   Street1: \"123 Main St\",\n    ...>   City: \"New York\",\n    ...>   State: \"NY\",\n    ...>   Postcode: \"10001\",\n    ...>   Country: 1\n    ...> }\n    iex> Deputy.My.update_contact_address(client, attrs)\n    {:ok, %{\"success\" => true}}","ref":"Deputy.My.html#update_contact_address/2-examples"},{"type":"module","title":"Deputy.Rosters","doc":"Functions for interacting with rosters in Deputy.","ref":"Deputy.Rosters.html"},{"type":"function","title":"Deputy.Rosters.copy/2","doc":"Copy rosters from one date range to another.","ref":"Deputy.Rosters.html#copy/2"},{"type":"function","title":"Parameters - Deputy.Rosters.copy/2","doc":"- `client`: A Deputy client.\n- `attrs`: A map containing the copy parameters.","ref":"Deputy.Rosters.html#copy/2-parameters"},{"type":"function","title":"Copy parameters - Deputy.Rosters.copy/2","doc":"- `strFromDate`: Start date of the source rosters in format \"YYYY-MM-DD\".\n- `strToDate`: Start date for the destination rosters in format \"YYYY-MM-DD\".\n- `intOperationalUnitArray`: Array of operational unit IDs to copy rosters for.\n- `blnRequireErrorDetails`: Optional. Whether to return detailed error information (1 for true, 0 for false).","ref":"Deputy.Rosters.html#copy/2-copy-parameters"},{"type":"function","title":"Examples - Deputy.Rosters.copy/2","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> attrs = %{\n    ...>   strFromDate: \"2023-01-01\",\n    ...>   strToDate: \"2023-01-08\",\n    ...>   intOperationalUnitArray: [1, 2],\n    ...>   blnRequireErrorDetails: 1\n    ...> }\n    iex> Deputy.Rosters.copy(client, attrs)\n    {:ok, %{\"success\" => true}}","ref":"Deputy.Rosters.html#copy/2-examples"},{"type":"function","title":"Deputy.Rosters.create/2","doc":"Create a new roster.","ref":"Deputy.Rosters.html#create/2"},{"type":"function","title":"Parameters - Deputy.Rosters.create/2","doc":"- `client`: A Deputy client.\n- `attrs`: A map containing the roster details.","ref":"Deputy.Rosters.html#create/2-parameters"},{"type":"function","title":"Examples - Deputy.Rosters.create/2","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> attrs = %{\n    ...>   intEmployeeId: 1,\n    ...>   intOperationalUnitId: 2,\n    ...>   intCompanyId: 3,\n    ...>   dtmStartTime: \"2023-01-01 09:00:00\",\n    ...>   dtmEndTime: \"2023-01-01 17:00:00\"\n    ...> }\n    iex> Deputy.Rosters.create(client, attrs)\n    {:ok, %{\"Id\" => 123}}","ref":"Deputy.Rosters.html#create/2-examples"},{"type":"function","title":"Deputy.Rosters.discard/2","doc":"Discard rosters.","ref":"Deputy.Rosters.html#discard/2"},{"type":"function","title":"Parameters - Deputy.Rosters.discard/2","doc":"- `client`: A Deputy client.\n- `attrs`: A map containing the discard parameters.","ref":"Deputy.Rosters.html#discard/2-parameters"},{"type":"function","title":"Discard parameters - Deputy.Rosters.discard/2","doc":"- `intRosterArray`: Array of roster IDs to discard.","ref":"Deputy.Rosters.html#discard/2-discard-parameters"},{"type":"function","title":"Examples - Deputy.Rosters.discard/2","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> attrs = %{intRosterArray: [400]}\n    iex> Deputy.Rosters.discard(client, attrs)\n    {:ok, %{\"success\" => true}}","ref":"Deputy.Rosters.html#discard/2-examples"},{"type":"function","title":"Deputy.Rosters.get/2","doc":"Get a specific roster by ID.","ref":"Deputy.Rosters.html#get/2"},{"type":"function","title":"Parameters - Deputy.Rosters.get/2","doc":"- `client`: A Deputy client.\n- `id`: The ID of the roster to retrieve.","ref":"Deputy.Rosters.html#get/2-parameters"},{"type":"function","title":"Examples - Deputy.Rosters.get/2","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> Deputy.Rosters.get(client, 1)\n    {:ok, %{\"Id\" => 1, \"StartTime\" => \"2023-01-01T09:00:00\"}}","ref":"Deputy.Rosters.html#get/2-examples"},{"type":"function","title":"Deputy.Rosters.get_available_for_swap/1","doc":"Get rosters available for swap.","ref":"Deputy.Rosters.html#get_available_for_swap/1"},{"type":"function","title":"Examples - Deputy.Rosters.get_available_for_swap/1","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> Deputy.Rosters.get_available_for_swap(client)\n    {:ok, [%{\"Id\" => 1, \"StartTime\" => \"2023-01-01T09:00:00\"}]}","ref":"Deputy.Rosters.html#get_available_for_swap/1-examples"},{"type":"function","title":"Deputy.Rosters.get_by_date/2","doc":"Get rosters for a specific date.","ref":"Deputy.Rosters.html#get_by_date/2"},{"type":"function","title":"Parameters - Deputy.Rosters.get_by_date/2","doc":"- `client`: A Deputy client.\n- `date`: The date to retrieve rosters for, in format \"YYYY-MM-DD\".","ref":"Deputy.Rosters.html#get_by_date/2-parameters"},{"type":"function","title":"Examples - Deputy.Rosters.get_by_date/2","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> Deputy.Rosters.get_by_date(client, \"2023-01-01\")\n    {:ok, [%{\"Id\" => 1, \"StartTime\" => \"2023-01-01T09:00:00\"}]}","ref":"Deputy.Rosters.html#get_by_date/2-examples"},{"type":"function","title":"Deputy.Rosters.get_by_date_and_location/3","doc":"Get rosters for a specific date and location.","ref":"Deputy.Rosters.html#get_by_date_and_location/3"},{"type":"function","title":"Parameters - Deputy.Rosters.get_by_date_and_location/3","doc":"- `client`: A Deputy client.\n- `date`: The date to retrieve rosters for, in format \"YYYY-MM-DD\".\n- `location_id`: The ID of the location.","ref":"Deputy.Rosters.html#get_by_date_and_location/3-parameters"},{"type":"function","title":"Examples - Deputy.Rosters.get_by_date_and_location/3","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> Deputy.Rosters.get_by_date_and_location(client, \"2023-01-01\", 1)\n    {:ok, [%{\"Id\" => 1, \"StartTime\" => \"2023-01-01T09:00:00\", \"CompanyId\" => 1}]}","ref":"Deputy.Rosters.html#get_by_date_and_location/3-examples"},{"type":"function","title":"Deputy.Rosters.get_recommendations/2","doc":"Get recommendations for a roster.","ref":"Deputy.Rosters.html#get_recommendations/2"},{"type":"function","title":"Parameters - Deputy.Rosters.get_recommendations/2","doc":"- `client`: A Deputy client.\n- `id`: The ID of the roster to get recommendations for.","ref":"Deputy.Rosters.html#get_recommendations/2-parameters"},{"type":"function","title":"Examples - Deputy.Rosters.get_recommendations/2","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> Deputy.Rosters.get_recommendations(client, 1)\n    {:ok, [%{\"EmployeeId\" => 123, \"Score\" => 85}]}","ref":"Deputy.Rosters.html#get_recommendations/2-examples"},{"type":"function","title":"Deputy.Rosters.list/1","doc":"Get a list of rosters from the last 12 hours and forward 36 hours.","ref":"Deputy.Rosters.html#list/1"},{"type":"function","title":"Examples - Deputy.Rosters.list/1","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> Deputy.Rosters.list(client)\n    {:ok, [%{\"Id\" => 1, \"StartTime\" => \"2023-01-01T09:00:00\"}]}","ref":"Deputy.Rosters.html#list/1-examples"},{"type":"function","title":"Deputy.Rosters.publish/2","doc":"Publish rosters.","ref":"Deputy.Rosters.html#publish/2"},{"type":"function","title":"Parameters - Deputy.Rosters.publish/2","doc":"- `client`: A Deputy client.\n- `attrs`: A map containing the publish parameters.","ref":"Deputy.Rosters.html#publish/2-parameters"},{"type":"function","title":"Publish parameters - Deputy.Rosters.publish/2","doc":"- `intMode`: Mode for publishing (e.g., 1).\n- `blnAllLocationsMode`: Whether to publish for all locations (1 for true, 0 for false).\n- `intRosterArray`: Array of roster IDs to publish.","ref":"Deputy.Rosters.html#publish/2-publish-parameters"},{"type":"function","title":"Examples - Deputy.Rosters.publish/2","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> attrs = %{\n    ...>   intMode: 1,\n    ...>   blnAllLocationsMode: 1,\n    ...>   intRosterArray: [400]\n    ...> }\n    iex> Deputy.Rosters.publish(client, attrs)\n    {:ok, %{\"success\" => true}}","ref":"Deputy.Rosters.html#publish/2-examples"},{"type":"module","title":"Deputy.Sales","doc":"Functions for interacting with sales metrics in Deputy.","ref":"Deputy.Sales.html"},{"type":"function","title":"Deputy.Sales.add_metrics/2","doc":"Add a sale to sales metrics.","ref":"Deputy.Sales.html#add_metrics/2"},{"type":"function","title":"Parameters - Deputy.Sales.add_metrics/2","doc":"- `client`: A Deputy client.\n- `metrics`: A map containing sales data.","ref":"Deputy.Sales.html#add_metrics/2-parameters"},{"type":"function","title":"Metrics parameters - Deputy.Sales.add_metrics/2","doc":"- `data`: Array of sale objects with the following fields:\n  - `timestamp`: Unix timestamp of the sale.\n  - `area`: ID of the area where the sale occurred.\n  - `type`: Type of metric (e.g., \"Sales\").\n  - `reference`: Reference ID for the sale.\n  - `value`: Sale amount.\n  - `employee`: Optional. ID of the employee who made the sale.\n  - `location`: ID of the location where the sale occurred.","ref":"Deputy.Sales.html#add_metrics/2-metrics-parameters"},{"type":"function","title":"Examples - Deputy.Sales.add_metrics/2","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> metrics = %{\n    ...>   data: [\n    ...>     %{\n    ...>       timestamp: 1660272300,\n    ...>       area: 2,\n    ...>       type: \"Sales\",\n    ...>       reference: \"API-Sales-Entry-1660272300\",\n    ...>       value: 100.30,\n    ...>       employee: 1,\n    ...>       location: 1\n    ...>     }\n    ...>   ]\n    ...> }\n    iex> Deputy.Sales.add_metrics(client, metrics)\n    {:ok, %{\"success\" => true}}","ref":"Deputy.Sales.html#add_metrics/2-examples"},{"type":"function","title":"Deputy.Sales.get_metrics/2","doc":"Retrieve sales data.","ref":"Deputy.Sales.html#get_metrics/2"},{"type":"function","title":"Parameters - Deputy.Sales.get_metrics/2","doc":"- `client`: A Deputy client.\n- `params`: A map containing query parameters.","ref":"Deputy.Sales.html#get_metrics/2-parameters"},{"type":"function","title":"Query parameters - Deputy.Sales.get_metrics/2","doc":"- `areas`: Comma-separated list of area IDs.\n- `types`: Comma-separated list of metric types (e.g., \"Sales\").\n- `start`: Unix timestamp for the start date.\n- `end`: Unix timestamp for the end date.","ref":"Deputy.Sales.html#get_metrics/2-query-parameters"},{"type":"function","title":"Examples - Deputy.Sales.get_metrics/2","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> params = %{\n    ...>   areas: \"1\",\n    ...>   types: \"Sales\",\n    ...>   start: \"1626203567\",\n    ...>   end: \"1657775576\"\n    ...> }\n    iex> Deputy.Sales.get_metrics(client, params)\n    {:ok, [%{\"timestamp\" => 1626203600, \"area\" => 1, \"type\" => \"Sales\", \"value\" => 100.30}]}","ref":"Deputy.Sales.html#get_metrics/2-examples"},{"type":"module","title":"Deputy.Timesheets","doc":"Functions for interacting with timesheets in Deputy.","ref":"Deputy.Timesheets.html"},{"type":"function","title":"Deputy.Timesheets.get_details/2","doc":"View timesheet details by ID.","ref":"Deputy.Timesheets.html#get_details/2"},{"type":"function","title":"Parameters - Deputy.Timesheets.get_details/2","doc":"- `client`: A Deputy client.\n- `id`: The ID of the timesheet to retrieve.","ref":"Deputy.Timesheets.html#get_details/2-parameters"},{"type":"function","title":"Examples - Deputy.Timesheets.get_details/2","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> Deputy.Timesheets.get_details(client, 123)\n    {:ok, %{\"Id\" => 123, \"StartTime\" => \"2023-01-01T09:00:00\"}}","ref":"Deputy.Timesheets.html#get_details/2-examples"},{"type":"function","title":"Deputy.Timesheets.pause/2","doc":"Pause or unpause an employee's timesheet (take a break/finish break).","ref":"Deputy.Timesheets.html#pause/2"},{"type":"function","title":"Parameters - Deputy.Timesheets.pause/2","doc":"- `client`: A Deputy client.\n- `attrs`: A map containing the timesheet details.","ref":"Deputy.Timesheets.html#pause/2-parameters"},{"type":"function","title":"Timesheet parameters - Deputy.Timesheets.pause/2","doc":"- `intTimesheetId`: ID of the timesheet to pause/unpause.","ref":"Deputy.Timesheets.html#pause/2-timesheet-parameters"},{"type":"function","title":"Examples - Deputy.Timesheets.pause/2","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> attrs = %{intTimesheetId: 123}\n    iex> Deputy.Timesheets.pause(client, attrs)\n    {:ok, %{\"success\" => true}}","ref":"Deputy.Timesheets.html#pause/2-examples"},{"type":"function","title":"Deputy.Timesheets.query/3","doc":"Search for timesheets using the resource API.","ref":"Deputy.Timesheets.html#query/3"},{"type":"function","title":"Parameters - Deputy.Timesheets.query/3","doc":"- `client`: A Deputy client.\n- `id`: Optional. The ID of a specific timesheet to retrieve.\n- `query`: Optional. A map containing search criteria.","ref":"Deputy.Timesheets.html#query/3-parameters"},{"type":"function","title":"Examples - Deputy.Timesheets.query/3","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> query = %{\n    ...>   search: %{id: %{field: \"Id\", type: \"eq\", data: 1}},\n    ...>   join: [\"TimesheetObject\"]\n    ...> }\n    iex> Deputy.Timesheets.query(client, nil, query)\n    {:ok, [%{\"Id\" => 1, \"StartTime\" => \"2023-01-01T09:00:00\"}]}\n\n    iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> Deputy.Timesheets.query(client, 1, nil)\n    {:ok, %{\"Id\" => 1, \"StartTime\" => \"2023-01-01T09:00:00\"}}","ref":"Deputy.Timesheets.html#query/3-examples"},{"type":"function","title":"Deputy.Timesheets.start/2","doc":"Start an employee's timesheet (clock on).","ref":"Deputy.Timesheets.html#start/2"},{"type":"function","title":"Parameters - Deputy.Timesheets.start/2","doc":"- `client`: A Deputy client.\n- `attrs`: A map containing the timesheet details.","ref":"Deputy.Timesheets.html#start/2-parameters"},{"type":"function","title":"Timesheet parameters - Deputy.Timesheets.start/2","doc":"- `intEmployeeId`: ID of the employee.\n- `intCompanyId`: ID of the company/location.\n- `intOperationalUnitId`: Optional. ID of the operational unit.\n- `intRosterId`: Optional. ID of the roster.\n- `startTime`: Optional. Start time in format \"YYYY-MM-DD HH:MM:SS\".","ref":"Deputy.Timesheets.html#start/2-timesheet-parameters"},{"type":"function","title":"Examples - Deputy.Timesheets.start/2","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> attrs = %{\n    ...>   intEmployeeId: 123,\n    ...>   intCompanyId: 456\n    ...> }\n    iex> Deputy.Timesheets.start(client, attrs)\n    {:ok, %{\"Id\" => 789}}","ref":"Deputy.Timesheets.html#start/2-examples"},{"type":"function","title":"Deputy.Timesheets.stop/2","doc":"Stop an employee's timesheet (clock off).","ref":"Deputy.Timesheets.html#stop/2"},{"type":"function","title":"Parameters - Deputy.Timesheets.stop/2","doc":"- `client`: A Deputy client.\n- `attrs`: A map containing the timesheet details.","ref":"Deputy.Timesheets.html#stop/2-parameters"},{"type":"function","title":"Timesheet parameters - Deputy.Timesheets.stop/2","doc":"- `intTimesheetId`: ID of the timesheet to stop.\n- `intMealbreakMinute`: Optional. Duration of meal break in minutes.","ref":"Deputy.Timesheets.html#stop/2-timesheet-parameters"},{"type":"function","title":"Examples - Deputy.Timesheets.stop/2","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> attrs = %{\n    ...>   intTimesheetId: 123,\n    ...>   intMealbreakMinute: 30\n    ...> }\n    iex> Deputy.Timesheets.stop(client, attrs)\n    {:ok, %{\"success\" => true}}","ref":"Deputy.Timesheets.html#stop/2-examples"},{"type":"module","title":"Deputy.Utility","doc":"Utility functions for interacting with Deputy system features.","ref":"Deputy.Utility.html"},{"type":"function","title":"Deputy.Utility.add_webhook/2","doc":"Add a webhook.","ref":"Deputy.Utility.html#add_webhook/2"},{"type":"function","title":"Parameters - Deputy.Utility.add_webhook/2","doc":"- `client`: A Deputy client.\n- `attrs`: A map containing the webhook details.","ref":"Deputy.Utility.html#add_webhook/2-parameters"},{"type":"function","title":"Webhook parameters - Deputy.Utility.add_webhook/2","doc":"- `Topic`: Event to subscribe to (e.g., \"Timesheet.Insert\").\n- `Enabled`: Whether the webhook is enabled (1 for true, 0 for false).\n- `Type`: Type of webhook (e.g., \"URL\").\n- `Address`: URL to send webhook events to.","ref":"Deputy.Utility.html#add_webhook/2-webhook-parameters"},{"type":"function","title":"Examples - Deputy.Utility.add_webhook/2","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> attrs = %{\n    ...>   Topic: \"Timesheet.Insert\",\n    ...>   Enabled: 1,\n    ...>   Type: \"URL\",\n    ...>   Address: \"https://example.com/webhook\"\n    ...> }\n    iex> Deputy.Utility.add_webhook(client, attrs)\n    {:ok, %{\"Id\" => 123}}","ref":"Deputy.Utility.html#add_webhook/2-examples"},{"type":"function","title":"Deputy.Utility.create_memo/2","doc":"Create a memo (announcement).","ref":"Deputy.Utility.html#create_memo/2"},{"type":"function","title":"Parameters - Deputy.Utility.create_memo/2","doc":"- `client`: A Deputy client.\n- `attrs`: A map containing the memo details.","ref":"Deputy.Utility.html#create_memo/2-parameters"},{"type":"function","title":"Memo parameters - Deputy.Utility.create_memo/2","doc":"- `strContent`: Content of the memo.\n- `intCompany`: ID of the company/location.\n- `blnRequireConfirm`: Whether confirmation is required (1 for true, 0 for false).","ref":"Deputy.Utility.html#create_memo/2-memo-parameters"},{"type":"function","title":"Examples - Deputy.Utility.create_memo/2","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> attrs = %{\n    ...>   strContent: \"Hello, this is a memo\",\n    ...>   intCompany: 1,\n    ...>   blnRequireConfirm: 0\n    ...> }\n    iex> Deputy.Utility.create_memo(client, attrs)\n    {:ok, %{\"Id\" => 123}}","ref":"Deputy.Utility.html#create_memo/2-examples"},{"type":"function","title":"Deputy.Utility.get_location_time/2","doc":"Retrieve current system time for a specific location.","ref":"Deputy.Utility.html#get_location_time/2"},{"type":"function","title":"Parameters - Deputy.Utility.get_location_time/2","doc":"- `client`: A Deputy client.\n- `location_id`: The ID of the location to get time for.","ref":"Deputy.Utility.html#get_location_time/2-parameters"},{"type":"function","title":"Examples - Deputy.Utility.get_location_time/2","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> Deputy.Utility.get_location_time(client, 1)\n    {:ok, %{\"time\" => 1672531200, \"tz\" => \"America/New_York\"}}","ref":"Deputy.Utility.html#get_location_time/2-examples"},{"type":"function","title":"Deputy.Utility.get_setup/1","doc":"Get setup information for the authenticated user (where can I work/what do I do).","ref":"Deputy.Utility.html#get_setup/1"},{"type":"function","title":"Examples - Deputy.Utility.get_setup/1","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> Deputy.Utility.get_setup(client)\n    {:ok, %{\"locations\" => [%{\"Id\" => 1, \"Name\" => \"Main Office\"}]}}","ref":"Deputy.Utility.html#get_setup/1-examples"},{"type":"function","title":"Deputy.Utility.get_time/1","doc":"Retrieve current system time.","ref":"Deputy.Utility.html#get_time/1"},{"type":"function","title":"Examples - Deputy.Utility.get_time/1","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> Deputy.Utility.get_time(client)\n    {:ok, %{\"time\" => 1672531200, \"tz\" => \"UTC\"}}","ref":"Deputy.Utility.html#get_time/1-examples"},{"type":"function","title":"Deputy.Utility.who_am_i/1","doc":"Get information about the authenticated user (who am I).","ref":"Deputy.Utility.html#who_am_i/1"},{"type":"function","title":"Examples - Deputy.Utility.who_am_i/1","doc":"iex> client = Deputy.new(base_url: \"https://test.deputy.com\", api_key: \"test-key\")\n    iex> Deputy.Utility.who_am_i(client)\n    {:ok, %{\"Id\" => 1, \"FirstName\" => \"John\", \"LastName\" => \"Doe\"}}","ref":"Deputy.Utility.html#who_am_i/1-examples"},{"type":"exception","title":"Deputy.Error.API","doc":"Represents an error returned by the Deputy API.","ref":"Deputy.Error.API.html"},{"type":"type","title":"Deputy.Error.API.t/0","doc":"","ref":"Deputy.Error.API.html#t:t/0"},{"type":"exception","title":"Deputy.Error.HTTP","doc":"Represents an HTTP-level error that occurred while communicating with the Deputy API.","ref":"Deputy.Error.HTTP.html"},{"type":"function","title":"Deputy.Error.HTTP.message/1","doc":"","ref":"Deputy.Error.HTTP.html#message/1"},{"type":"type","title":"Deputy.Error.HTTP.t/0","doc":"","ref":"Deputy.Error.HTTP.html#t:t/0"},{"type":"exception","title":"Deputy.Error.ParseError","doc":"Represents an error that occurred while parsing the API response.","ref":"Deputy.Error.ParseError.html"},{"type":"type","title":"Deputy.Error.ParseError.t/0","doc":"","ref":"Deputy.Error.ParseError.html#t:t/0"},{"type":"exception","title":"Deputy.Error.RateLimitError","doc":"Represents a rate limit error from the Deputy API.","ref":"Deputy.Error.RateLimitError.html"},{"type":"function","title":"Deputy.Error.RateLimitError.message/1","doc":"","ref":"Deputy.Error.RateLimitError.html#message/1"},{"type":"type","title":"Deputy.Error.RateLimitError.t/0","doc":"","ref":"Deputy.Error.RateLimitError.html#t:t/0"},{"type":"exception","title":"Deputy.Error.ValidationError","doc":"Represents an error that occurred while validating request parameters.","ref":"Deputy.Error.ValidationError.html"},{"type":"type","title":"Deputy.Error.ValidationError.t/0","doc":"","ref":"Deputy.Error.ValidationError.html#t:t/0"},{"type":"extras","title":"Deputy","doc":"# Deputy\n\n[![Hex Version](https://img.shields.io/hexpm/v/deputy.svg)](https://hex.pm/packages/deputy)\n[![Hex Docs](https://img.shields.io/badge/docs-hexpm-blue.svg)](https://hexdocs.pm/deputy/)\n\nAn Elixir client for the [Deputy](https://www.deputy.com/) API,\norganized by resource type.","ref":"readme.html"},{"type":"extras","title":"Installation - Deputy","doc":"This package can be installed by adding `deputy` to your list of dependencies in\n`mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:deputy, \"~> 0.2.1\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Getting Started - Deputy","doc":"First, create a new Deputy client with your API credentials:\n\n```elixir\nclient = Deputy.new(\n  base_url: \"https://your-subdomain.deputy.com\",\n  api_key: \"your-api-key\"\n)\n```\n\nThen, use the client to interact with the Deputy API:\n\n```elixir\n# Get locations\n{:ok, locations} = Deputy.Locations.list(client)\n\n# Get employees\n{:ok, employees} = Deputy.Employees.list(client)\n```","ref":"readme.html#getting-started"},{"type":"extras","title":"API Modules - Deputy","doc":"The library is organized into modules by resource type:\n\n- `Deputy.Locations` - Manage locations (companies)\n- `Deputy.Employees` - Manage employees\n- `Deputy.Departments` - Manage departments (operational units)\n- `Deputy.Rosters` - Manage rosters (schedules)\n- `Deputy.Timesheets` - Manage timesheets\n- `Deputy.Sales` - Manage sales metrics\n- `Deputy.Utility` - Utility functions (time, memos, webhooks, etc.)\n- `Deputy.My` - Access endpoints related to the authenticated user\n\nEach module provides functions for interacting with the corresponding Deputy API endpoints.","ref":"readme.html#api-modules"},{"type":"extras","title":"Error Handling - Deputy","doc":"All API functions return either `{:ok, result}` or `{:error, error}` tuples. The error can be one of several types:\n\n- `%Deputy.Error.API{}` - API error with details from Deputy (status, code, message)\n- `%Deputy.Error.HTTP{}` - HTTP-level error (network issues, server errors)\n- `%Deputy.Error.ParseError{}` - Error parsing the API response\n- `%Deputy.Error.ValidationError{}` - Request validation failed\n- `%Deputy.Error.RateLimitError{}` - Rate limit exceeded\n\nExample of handling different error types:\n\n```elixir\ncase Deputy.Locations.get(client, 12345) do\n  {:ok, location} ->\n    # Process location data\n    IO.inspect(location)\n\n  {:error, %Deputy.Error.API{status: 404}} ->\n    # Handle not found error\n    IO.puts(\"Location not found\")\n\n  {:error, %Deputy.Error.HTTP{reason: reason}} ->\n    # Handle HTTP error\n    IO.puts(\"HTTP error: #{inspect(reason)}\")\n\n  {:error, %Deputy.Error.RateLimitError{retry_after: seconds}} ->\n    # Handle rate limit\n    IO.puts(\"Rate limited. Try again in #{seconds} seconds\")\nend\n```","ref":"readme.html#error-handling"},{"type":"extras","title":"Bang Functions - Deputy","doc":"Each API function has a corresponding bang (!) version that raises an exception\ninstead of returning an error tuple. This is useful when you want to fail fast\nif an error occurs.\n\n```elixir\n# Using regular function with error tuple\n{:ok, locations} = Deputy.Locations.list(client)\n\n# Using bang version that raises an exception on error\nlocations = Deputy.Locations.list!(client)\n```","ref":"readme.html#bang-functions"},{"type":"extras","title":"Examples - Deputy","doc":"","ref":"readme.html#examples"},{"type":"extras","title":"Working with Locations - Deputy","doc":"```elixir\n# List all locations\n{:ok, locations} = Deputy.Locations.list(client)\n# Or using the bang version\nlocations = Deputy.Locations.list!(client)\n\n# Get a specific location\n{:ok, location} = Deputy.Locations.get(client, 123)\n# Or using the bang version\nlocation = Deputy.Locations.get!(client, 123)\n\n# Create a new location\nattrs = %{\n  strWorkplaceName: \"New Location\",\n  strWorkplaceCode: \"NLC\",\n  strAddress: \"123 Test St\",\n  intIsWorkplace: 1,\n  intIsPayrollEntity: 1,\n  strTimezone: \"America/New_York\"\n}\n{:ok, new_location} = Deputy.Locations.create(client, attrs)\n\n# Update a location with error handling\ncase Deputy.Locations.update(client, 123, %{strWorkplaceCode: \"UPD\"}) do\n  {:ok, updated} ->\n    IO.puts(\"Location updated successfully\")\n\n  {:error, %Deputy.Error.API{status: 404}} ->\n    IO.puts(\"Location not found\")\n\n  {:error, %Deputy.Error.ValidationError{message: message}} ->\n    IO.puts(\"Validation error: #{message}\")\nend\n```","ref":"readme.html#working-with-locations"},{"type":"extras","title":"Working with Employees - Deputy","doc":"```elixir\n# List all employees\n{:ok, employees} = Deputy.Employees.list(client)\n# Or using the bang version\nemployees = Deputy.Employees.list!(client)\n\n# Get a specific employee with error handling for rate limits\ncase Deputy.Employees.get(client, 123) do\n  {:ok, employee} ->\n    IO.inspect(employee)\n\n  {:error, %Deputy.Error.RateLimitError{retry_after: seconds}} ->\n    Process.sleep(seconds * 1000)\n    # Retry after waiting\n    {:ok, employee} = Deputy.Employees.get(client, 123)\nend\n\n# Create a new employee\nattrs = %{\n  strFirstName: \"John\",\n  strLastName: \"Doe\",\n  intCompanyId: 1,\n  intGender: 1,\n  strCountryCode: \"US\",\n  strDob: \"1980-01-01\",\n  strStartDate: \"2023-01-01\",\n  strMobilePhone: \"5551234567\"\n}\n\n# Using the bang version with exception rescue\ntry do\n  new_employee = Deputy.Employees.create!(client, attrs)\n  IO.puts(\"Employee created successfully\")\nrescue\n  e in Deputy.Error.ValidationError ->\n    IO.puts(\"Validation error: #{e.message}\")\n  e in Deputy.Error.API ->\n    IO.puts(\"API error (#{e.status}): #{e.message}\")\nend\n```","ref":"readme.html#working-with-employees"},{"type":"extras","title":"Working with Timesheets - Deputy","doc":"```elixir\n# Start a timesheet using the bang version\ntimesheet = Deputy.Timesheets.start!(client, %{\n  intEmployeeId: 123,\n  intCompanyId: 456\n})\n\n# Stop a timesheet with error handling\ncase Deputy.Timesheets.stop(client, %{intTimesheetId: 789}) do\n  {:ok, result} ->\n    IO.puts(\"Timesheet stopped successfully\")\n\n  {:error, %Deputy.Error.API{status: 404}} ->\n    IO.puts(\"Timesheet not found\")\n\n  {:error, %Deputy.Error.API{status: 400, message: message}} ->\n    IO.puts(\"Bad request: #{message}\")\n\n  {:error, %Deputy.Error.HTTP{reason: reason}} ->\n    IO.puts(\"HTTP error: #{inspect(reason)}\")\nend\n\n# Get timesheet details\n{:ok, details} = Deputy.Timesheets.get_details(client, 789)\n# Or using the bang version\ndetails = Deputy.Timesheets.get_details!(client, 789)\n```","ref":"readme.html#working-with-timesheets"},{"type":"extras","title":"Working with Authenticated User Data - Deputy","doc":"```elixir\n# Get information about the authenticated user\n{:ok, user} = Deputy.My.me(client)\n# Or using the bang version\nuser = Deputy.My.me!(client)\n\n# Get locations where the authenticated user can work\n{:ok, locations} = Deputy.My.locations(client)\n\n# Get the authenticated user's rosters with error handling\ncase Deputy.My.rosters(client) do\n  {:ok, rosters} ->\n    IO.inspect(rosters)\n\n  {:error, %Deputy.Error.API{status: status, message: message}} ->\n    IO.puts(\"API error (#{status}): #{message}\")\n\n  {:error, %Deputy.Error.HTTP{reason: :timeout}} ->\n    IO.puts(\"Request timed out, try again later\")\n\n  {:error, error} ->\n    IO.puts(\"Unexpected error: #{inspect(error)}\")\nend\n\n# Get the authenticated user's timesheets\ntimesheets = Deputy.My.timesheets!(client)\n```","ref":"readme.html#working-with-authenticated-user-data"},{"type":"extras","title":"Testing - Deputy","doc":"You can test your code that uses this library by leveraging the\n`Deputy.HTTPClient.Mock` provided for testing. This allows you to mock the API\nresponses in your tests.\n\n```elixir\n# In your test setup\nMox.defmock(Deputy.HTTPClient.Mock, for: Deputy.HTTPClient.Behaviour)\n\ntest \"list employees success\" do\n  client = Deputy.new(\n    base_url: \"https://test.deputy.com\",\n    api_key: \"test-key\",\n    http_client: Deputy.HTTPClient.Mock\n  )\n\n  # Set up expectations for success\n  Deputy.HTTPClient.Mock\n  |> expect(:request, fn opts ->\n    assert Keyword.get(opts, :method) == :get\n    assert Keyword.get(opts, :url) == \"https://test.deputy.com/api/v1/supervise/employee\"\n\n    {:ok, [%{\"Id\" => 1, \"FirstName\" => \"John\", \"LastName\" => \"Doe\"}]}\n  end)\n\n  # Call the function\n  {:ok, employees} = Deputy.Employees.list(client)\n\n  # Assertions\n  assert length(employees) == 1\n  assert hd(employees)[\"FirstName\"] == \"John\"\nend\n\ntest \"list employees error handling\" do\n  client = Deputy.new(\n    base_url: \"https://test.deputy.com\",\n    api_key: \"test-key\",\n    http_client: Deputy.HTTPClient.Mock\n  )\n\n  # Set up expectations for error\n  Deputy.HTTPClient.Mock\n  |> expect(:request, fn _opts ->\n    error = Deputy.Error.from_response(%{\n      status: 403,\n      body: %{\"error\" => %{\"code\" => \"permission_denied\", \"message\" => \"Permission denied\"}}\n    })\n    {:error, error}\n  end)\n\n  # Call the function and test error handling\n  assert {:error, %Deputy.Error.API{status: 403, code: \"permission_denied\"}} =\n    Deputy.Employees.list(client)\n\n  # Test bang version raises exception\n  assert_raise Deputy.Error.API, fn ->\n    Deputy.Employees.list!(client)\n  end\nend\n```","ref":"readme.html#testing"},{"type":"extras","title":"Documentation - Deputy","doc":"Detailed documentation can be found at  .","ref":"readme.html#documentation"},{"type":"extras","title":"License - Deputy","doc":"Deputy is [released under the MIT license](LICENSE).","ref":"readme.html#license"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nAll notable changes to this project will be documented in this file. See [Keep a\nCHANGELOG](http://keepachangelog.com/) for how to update this file. This project\nadheres to [Semantic Versioning](http://semver.org/).\n\n<!-- %% CHANGELOG_ENTRIES %% -->","ref":"changelog.html"},{"type":"extras","title":"0.2.1 - 2025-03-04 - Changelog","doc":"","ref":"changelog.html#0-2-1-2025-03-04"},{"type":"extras","title":"Changes - Changelog","doc":"- Fixed changelog URL in package metadata","ref":"changelog.html#changes"},{"type":"extras","title":"0.2.0 - 2025-03-04 - Changelog","doc":"","ref":"changelog.html#0-2-0-2025-03-04"},{"type":"extras","title":"Changes - Changelog","doc":"- Introduce centralised error types and handling functions.\n- Improve presentation of package documentation.\n- Update package metadata with additional links, etc.","ref":"changelog.html#changes"},{"type":"extras","title":"0.1.0 - 2025-03-03 - Changelog","doc":"Initial version. :rocket:","ref":"changelog.html#0-1-0-2025-03-03"},{"type":"extras","title":"LICENSE","doc":"MIT License\n\nCopyright (c) 2025 Sasha Gerrand\n\nPermission is hereby granted, free of charge, to any person obtaining\na copy of this software and associated documentation files (the\n\"Software\"), to deal in the Software without restriction, including\nwithout limitation the rights to use, copy, modify, merge, publish,\ndistribute, sublicense, and/or sell copies of the Software, and to\npermit persons to whom the Software is furnished to do so, subject to\nthe following conditions:\n\nThe above copyright notice and this permission notice shall be\nincluded in all copies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND,\nEXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF\nMERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND\nNONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE\nLIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION\nOF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION\nWITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.","ref":"license.html"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.2"}}